[![Latest PyPI release](https://img.shields.io/pypi/v/pywikibot-extensions?logo=pypi)](https://pypi.org/project/pywikibot-extensions) ![Latest GitHub release](https://img.shields.io/github/v/release/JJMC89/pywikibot-extensions?logo=github) ![Latest tag](https://img.shields.io/github/v/tag/JJMC89/pywikibot-extensions?logo=git)

![License](https://img.shields.io/pypi/l/pywikibot-extensions?color=blue) ![Python versions](https://img.shields.io/pypi/pyversions/pywikibot-extensions?logo=python)

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/JJMC89/pywikibot-extensions/main.svg)](https://results.pre-commit.ci/latest/github/JJMC89/pywikibot-extensions/main) [![CI](https://github.com/JJMC89/pywikibot-extensions/actions/workflows/ci.yaml/badge.svg?branch=main)](https://github.com/JJMC89/pywikibot-extensions/actions?query=workflow%3ACI+branch%3Amain)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# pywikibot-extensions
The pywikibot-extensions library extends the [Pywikibot](https://pywikibot.org) library.

## Installation
`pip install pywikibot-extensions`
